"""
Setup script for atx-mainframe-dependency-manager.
This file is kept for backward compatibility.
The actual configuration is in pyproject.toml.
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
